#
# spec file for package hamster-time-tracker
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           hamster-time-tracker
Version:        1.04+0
Release:        1.1
Summary:        A time tracker for GNOME
License:        GPL-3.0+ and CC-BY-SA-3.0
Group:          Productivity/Other
Url:            https://github.com/projecthamster/hamster
Source:         %{name}-%{version}.tar.xz
# PATCH-FEATURE-UPSTREAM https://github.com/projecthamster/hamster/pull/336
Patch0:         appdata.patch
BuildRequires:  fdupes
BuildRequires:  gconf2-devel
BuildRequires:  glib2-devel
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  intltool
BuildRequires:  python-devel
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gnome-keybindings)
# Note:
# - we do not have the gnomeapplet bindings anymore (it doesn't work with
#   GNOME 3), so we don't add a Requires/Recommends for it.
# - the gnome python module is needed only for the applet, and since we don't
#   have it, we don't need a dependency on python-gnome
Requires:       dbus-1-python
Requires:       python-gconf
Requires:       python-gtk
Requires:       python-wnck
Requires:       python-xdg
Recommends:     %{name}-lang
Recommends:     python-evolution
# hamster-time-tracker used to be developed as hamster-applet. Last ever release was 2.91.2
Obsoletes:      docky-hamster-applet <= 2.91.2
Obsoletes:      hamster-applet <= 2.91.2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%{py_requires}
%gconf_schemas_prereq

%description
Project Hamster is time tracking for masses. It helps you to keep track
on how much time you have spent during the day on activities you have
set up.

%lang_package
%prep
%setup -q -n %{name}-%{version}
%patch0 -p1

%build
./waf --prefix=%{_prefix} configure build

%install
./waf install --destdir=%{buildroot} --libdir=%{_libdir} --libexecdir=%{_libexecdir}
%find_gconf_schemas
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file hamster-time-tracker X-SuSE-TimeUtility
%suse_update_desktop_file hamster-time-tracker-overview X-SuSE-TimeUtility
%fdupes %{buildroot}

%pre -f %{name}.schemas_pre

%post
%desktop_database_post
%icon_theme_cache_post

%preun -f %{name}.schemas_preun

%postun
%desktop_database_postun
%icon_theme_cache_postun

%posttrans -f %{name}.schemas_posttrans

%files -f %{name}.schemas_list
%defattr(-, root, root)
%doc AUTHORS NEWS
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/%{name}/
%doc %{_datadir}/gnome/help/%{name}/C/
%{_bindir}/hamster
%{_datadir}/applications/hamster-time-tracker.desktop
%{_datadir}/applications/hamster-time-tracker-overview.desktop
%{_datadir}/applications/hamster-windows-service.desktop
%{_datadir}/dbus-1/services/org.gnome.hamster.service
%{_datadir}/dbus-1/services/org.gnome.hamster.Windows.service
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%{_datadir}/%{name}/
%{_libexecdir}/%{name}/
%{python_sitelib}/hamster/
%{_sysconfdir}/bash_completion.d/hamster.bash
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%files lang -f %{name}.lang

%changelog
* Fri Mar 24 2017 mwilck@suse.com
- spec file: removed obsolete %%clean section
* Thu Feb 16 2017 martin.wilck@suse.com
- Update to version 1.04+0:
  * Build from github, using _service file (localonly mode)
- Fix email address in .changes file.
* Tue Oct  4 2016 mailaender@opensuse.org
- Add appdata.xml for https://en.opensuse.org/openSUSE:AppStore
* Sun Jan 19 2014 zaitor@opensuse.org
- Update to version 1.04:
  + Bugfixes around talking to the notifications daemon.
  + Updating tags list in prefs wasn't doing anything.
  + In some cases activity updates were failing when tags where
    provided.
* Fri Feb  8 2013 dimstar@opensuse.org
- Update to version 1.03.3 (bnc#802601):
  + Fix exporting entries to file.
- Changes from version 1.03.2:
  + Fix bug when trying to enter an activity with tags.
- Changes from version 1.03.1:
  + Fix silly bug with path.
- Changes from version 1.03:
  + Fix issue #61: installation was missing initial database for
    fresh installs
  + Loosen backend dependencies so that hamster.client can be used
    outside the project.
  + Desktop notification now once again correctly notifies of
    "No activity"
* Tue Jan 15 2013 cfarrell@suse.com
- license update: GPL-3.0+ and CC-BY-SA-3.0
  A substantial number of content files found with CC-BY-SA-3.0 license
* Mon Jan 14 2013 dimstar@opensuse.org
- Rename to hamster-time-tracker, following upstream
- Update to version 1.02.1:
  + Drop gnome-keybindings as a dependency.
- Changes from version 1.02:
  + Project Hamster has detached from Gnome and thus we are
    resetting the versioning. The program name also has changed
    from hamster-applet to a more generic hamster-time-tracker
  + Improvements in the command line. hamster-cli has been renamed
    to simply "hamster" and without parameters launches the day
    view. Run "hamster --help" to get help on available commands.
    The executable also supports tab-completion to suggest actions
    as well as to look up activities and categories
  + Desktop notifications are back
  + The notification tray interaction has been slightly improved
  + ~20 bug fixes.
- Obsolete hamster-applet and docky-hamster-applet <= 2.91.2 (last
  release prior the rename by upstream).
- Note: docky-hamster-applet has been completely dropped for now.
- Change python-evolution Requires to Recommends: h-t-t can work
  without evolution support and on recent evo-versions, there are
  no python bindings available.
* Thu Jun  9 2011 vuntz@opensuse.org
- Update dependencies to be more specific:
  + Add python-evolution, python-gconf and python-wnck Requires
    since those modules are explicitly used.
  + Drop gnome-python-desktop and python-gnome Requires: we
    explicitly have the Requires we need now, and so we don't need
    those more generic meta-packages.
  + Add a comment about the gnomeapplet python module, and why it
    is not needed anymore with GNOME 3.
- Drop gnome-python-desktop BuildRequires that was there only for
  directory ownership, and instead remove the .server file for the
  GNOME 2 applet since we can't use it.
* Fri Mar  4 2011 fcrozat@novell.com
- Update to version 2.91.2:
  + Experimental trophy support (gnome-achievements is needed for
    this, see fate#312280).
  + Improvements in HTML reports
  + Updated translations
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Wed Dec 15 2010 vuntz@opensuse.org
- Add gnome-python-desktop BuildRequires (which is already a
  Requires), for directory ownership, to fix build.
- Move the dockmanager files to docky-hamster-applet.
* Tue Nov 16 2010 dimstar@opensuse.org
- Update to version 2.32.1:
  + Totals are returned to HTML report
  + Fixed problems with the stop button and python 2.7
  + Ampersand now is safe to use again
  + Updated translations.
- Add python-xdg Requires. Fix bnc#653578.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Fixed bug with stale cache in description label
  + Updated translations.
* Mon Sep 13 2010 vuntz@opensuse.org
- Update to version 2.31.92:
  + Minor bugfixes
  + Updated translations.
* Mon Aug 30 2010 vuntz@opensuse.org
- Update to version 2.31.91:
  + Data integrity bugfixes
  + Updated translations.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 2.31.90:
  + Maintaining selection on refresh in a more sane manner
  + Self-monitor the database not only for updates but also for
    remove/create (solves problems with some synchronization tools)
  + Fixed the global hotkey, require gnome-keybindings package as
    the hotkey is part of expected functionality
  + Updated translations.
- Add pkgconfig(gnome-keybindings) BuildRequires.
* Sun Aug  8 2010 vuntz@opensuse.org
- Remove unneeded BuildRequires: gnome-control-center-devel,
  gnome-python-desktop, gtk2-devel, python-gnome-devel,
  python-gtk-devel.
- Add glib2-devel BuildRequires.
* Thu Aug  5 2010 vuntz@opensuse.org
- Update to version 2.31.6:
  + the top graph in overview is now interactive and allows zooming
    in and out
  + sqlite utf-8 case sensitivity workarounds for queries
  + hamster's docky helper installed together with hamster
  + using full text search in the overview window now
  + hopefully activity trees now behave better on refresh
  + updated translations
- Changes from version 2.31.5:
  + adjustments for custom widgets to better work with themes
  + if dialog windows are called from commandline, make sure they
    shut down properly
  + updated translations
- Make package noarch.
- Call %%suse_update_desktop_file for hamster-applet.desktop
- Create a docky-hamster-applet subpackage for the docky
  integration.
* Thu Jul  8 2010 dimstar@opensuse.org
- Update to version 2.31.4:
  + overview gets a menu, drops toolbars and now supports date
    range browsing
  + adjustments to starts and ends graph in statistics (should be
    more accurate)
  + performance updates in graphics
  + html report was looking in the wrong place for the template
- Changes from version 2.31.3.2:
  + bgo#620965: respecting SYSCONFDIR environment variable to
    determine where to store gconf schema
- Changes from version 2.31.3.1:
  + including generated help pages in the tarball
- Changes from version 2.31.3:
  + dropped in-house global hotkey management in favour to Gnome's
    global hotkeys
  + HTML report template now can be overridden from $HOME folder.
    instructions can be found in the report footer
  + remembering path of last saved report
  + moved build system from autotools to waf
- Changes from version 2.31.2:
  + optional integration with gtg (via preferences)
  + all kinds of bugfixes
- Changes from version 2.31.1.2:
  + add missing file from tarball
- Changes from version 2.31.1.1:
  + add missing translations
- Changes from version 2.31.1:
  + application has been split up in back-end d-bus daemon and
    clients
  + edit activity preview widget got some love
  + minor bugfixes from 2.30 release
  + updated translations
- Adapt spec file to use waf instead of configure.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.30.1:
  + translations were not appearing in standalone
  + database file change monitor now follows symlinks
  + fixed rounding error in totals  (regression)
  + standalone can be now closed using standard Ctrl+w keystroke
  + updated translations.
* Wed Mar 31 2010 vuntz@opensuse.org
- Update to version 2.30.0.1:
  + bgo#614452 - load translations in standalone mode
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Updated translations.
* Mon Mar  8 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + depend on gnome-python-desktop to fulfill wnck-python
    dependency
  + minor bug with screen refresh after deletion
  + Updated translations.
* Wed Feb 24 2010 dimstar@opensuse.org
- Update to version 2.29.91:
  + avoiding blank entries, not reusing fact ids; other details
  + Updated translations.
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 2.29.90:
  + Updated translations.
- Add back the gconf packaging magic.
* Tue Jan 26 2010 vuntz@opensuse.org
- Update to version 2.29.6:
  + workspace tracking - switch activity, when switching desktops
  + chart improvements - theme friendly and less noisier
  + for those without GNOME panel there is now a standalone
    version, accessible via Applications -> Accessories -> Time
    Tracker
  + overview window remembers position
  + maintaining cursor on the selected row after edits / refreshes
    (unimportant, but very convenient)
  + descriptions once again in the main input field, delimited by
    comma
  + activity suggestion box now sorts items by recency
  + updated translations
- Add gnome-doc-utils-devel BuildRequires.
- Add gnome-control-center-devel BuildRequires to support custom
  keybindings.
- Remove all the gconf packaging magic since the gconf schemas were
  removed, but this might come back (see bgo#608252).
- Update new desktop file with the X-SuSE-TimeUtility category.
* Thu Jan 14 2010 captain.magnus@opensuse.org
- Update to version 2.29.5:
  + searching
  + simplified save report dialog, thanks to the what you see is
    what you report revamp
  + overview/stats replaced with activities / totals and stats
    accessible from totals
  + interactive graphs to drill down in totals
  + miscellaneous performance improvements
  + pixel-perfect graphs
* Tue Dec 22 2009 lmedinas@opensuse.org
- Update to version 2.29.4:
  + Overview window overhaul (still in progress)
  + More progress on tag front (now showing in lists)
  + Updated translations.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 2.29.3:
  + partial tag support (adding to a fact and editing autocomplete
    list, no reports yet)
  + fixed glitches when editing ongoing task
  + improved save report dialog
  + better autocomplete for the entries
  + Updated translations.
- Changes from version 2.29.2:
  + bgo#599343 - the charts are now back again (for those who had
    lost them)
  + hamster midnight is now a preference
  + when in panel, printing uncaught errors to .xsession-errors
  + when looking for ongoing task, don't look into the future
    (causes some mad durations and is generally impractical)
  + new dbus method getCurrentActivity that returns just the name
    and category
  + fixed problems with hamster interfering with screensaver
    hibernation code
  + database MOVED to the xdg home (~/.local)
  + in reports inlude also activities without category
  + set start time to the end of the last activity if adding
    previous activity for today
  + fixes to the dropdown in compiz (not spanning over virtual
    desktops anymore)
  + in dropdown added end time and dropped the stripes (too much
    noise already)
  + Updated translations.
- Pass --disable-schemas-install to configure.
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 2.28.1:
  + Avoid getting activities from the future (bgo#596617)
  + Updated translations.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated translations.
* Tue Sep  8 2009 dimstar@opensuse.org
- Update to version 2.27.92:
  + Updated translations.
* Tue Aug 11 2009 lmedinas@gmail.com
- Update to version 2.27.90:
  + Fixes to idle detection
  + Return of the day view
  + UI layout fixes to match HIG
  + Now it is possible to add more than one applet to panel without
    crashing
  + Updated translations
* Tue Jul 28 2009 lmedinas@gmail.com
- Update to version 2.27.5:
  + Better autocomplete
  + More skeptic on parsing time
  + Legend in overview is sized proportionally to screen size,
    allowing larger labels
  + Translation updates.
* Sun Jul 19 2009 lmedinas@gmail.com
- Update to version 2.27.4:
  + Now it is possible to copy/paste activities in the overview
  + Mostly polishing and bug fixing the new stuff brought in 2.27
    cycle
  + Translation updates
* Tue Jun 16 2009 vuntz@novell.com
- Update to version 2.27.3:
  + A much better DBUS support
  + Switch days at 5am because humans tend to work late.
    Overlapping activities fall in day where the largest part of it
    is
  + Now you can enter negatives minutes to start an activity in
    past. Example "-30 cookies" will start activity "cookies" 30
    minutes before now
  + TSV, XML and iCal export
  + Ability to filter task by date and category
  + Overview has been improved by adding some nifty statistics for
    your pleasure
  + Updated translations.
- Add dbus-1-python Requires.
* Wed May 27 2009 vuntz@novell.com
- Update to version 2.27.2:
  + Now a reminder is displayed every configured amount of time
    also when no activity is being tracked.
  + Allow to switch to same task if description differs.
  + Activity edit icon in dropdown is now keyboard accessible.
  + Start time and end time can be specified when typing in task.
    Example: 00:04 Hamster
  + Slightly smarter autocomplete with category suggestions when
    after @ symbol
  + Fixes to edit activity dialog's end time field.
  + Updated translations.
* Tue May  5 2009 vuntz@novell.com
- Update to version 2.27.1:
  + Overview window graphs have been redone and now are less noisy
  + Tasks now can span over midnight, showing correct per-day
    totals in overview
  + Add earlier activity / edit activity has been overhauled and
    now is much easier to use. An experimental preview has been
    added
  + In preferences UI buttons have been added for editing and
    deletion
  + Glade files have been migrated to gtkbuilder format
  + Now it is possible to start overview and other windows straight
    from command line using "-s [stats|edit|prefs]" switch
  + Updated translations.
* Mon Mar 16 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Final fixes to utf-8 and Python 2.6 sqlite.
  + Updated translations.
- Remove AutoReqProv: it's default now.
- Use parallel make.
* Sun Mar  8 2009 vuntz@novell.com
- Review changes.
* Wed Mar  4 2009 lmedinas@gmail.com
- Update to version 2.25.92:
  + Fixed problems with utf-8 and Python 2.6 sqlite
  + Escaping user input so they don't break UI where pango is used
  + Stop tracking on shutdown was ignoring user preference
  + Translation updates
* Mon Feb 16 2009 mboman@suse.de
- Update to version 2.25.91:
  + Show day totals in statistics
  + Better keyboard support (Enter / Escape)
  + Fixes to detect alternative pygtk
  + Fixes to support Japanese better
  + Python 2.6 support
  + Better duplicate entry checks in activities / categories
  + Translation updates
- Remove checks for <= 10.2
- Remove gnome-common and perl-XML-Parser from BuildRequires
* Sat Feb 14 2009 mboman@suse.de
- Remove python-sqlite2 from Requires
* Fri Feb  6 2009 hfiguiere@suse.de
- Review and approve
- Fix dependencies
* Thu Feb  5 2009 lmedinas@gmail.com
- Update to 2.25.90
  + Locales fixes
  + Fix checks for python 2.6 and 3.0
  + Translation Updates
- Update homepage url
- Use %%%%fdupes
* Wed Jan 14 2009 awafaa@opensuse.org
- Update to 2.24.3
* Thu Apr 24 2008 maw@suse.de
- Improve package's metadata
- Build on 10.2
- Require things that should be required.
* Thu Apr 24 2008 maw@suse.de
- Initial hamster-applet package: version 0.2.
